CEKit
=====

.. image:: https://github.com/cekit/cekit/raw/develop/docs/_static/logo-wide.png

About
-----

Container image creation tool.

CEKit helps to build container images from image definition files with strong
focus on modularity and code reuse.

Features
--------

* Building container images  from YAML image definitions
* Integration/unit testing of images

Documentation
-------------

`Documentation is available here <http://cekit.readthedocs.io/>`_.
